==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-sensors/sensors_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation type="vanished">Nastavení čidel</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Běžné</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Obnovovací interval (v sekundách)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Šířka proužku s teplotou</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Teplotní stupnice</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Celsius</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Fahrenheit</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Blikat proužky ukazujícími nárůst teploty, když je teplota příliš vysoká</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Varování při vysoké teplotě</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Čidla</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Zjištěné čipy:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Vlastnosti čipů:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Enabled</source>
        <translation>Povoleno</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Label</source>
        <translation>Štítek</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-sensors/sensors_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation>Nastavení čidel</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Nastavení čidel</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Běžné</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Obnovovací interval (v sekundách)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Šířka proužku s teplotou</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Teplotní stupnice</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Celsius</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Fahrenheit</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Blikat proužky ukazujícími nárůst teploty, když je teplota příliš vysoká</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Varování při vysoké teplotě</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Čidla</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Zjištěné čipy:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Vlastnosti čipů:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>Povoleno</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>Štítek</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
</context>
</TS>
